==> 0.0.36.tar.gz: lib/src/widgets/smiley_add_widget.dart <==
import 'package:flutter/material.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_story/src/models/basic.dart';

class SmileyAddWidget extends StatefulWidget {
  final Function(SmileyData smileyData) onSelected;

  const SmileyAddWidget({Key key, @required this.onSelected}) : super(key: key);
  @override
  State<StatefulWidget> createState() => _SmileyAddWidgetState();
}

class _SmileyAddWidgetState extends State<SmileyAddWidget> {
  final GlobalKey<ScaffoldState> key = GlobalKey<ScaffoldState>();
  AnimationController controller;
  List<String> smilies = ["sticker1", "sticker2", "sticker3", "sticker4"];
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () async {
        widget.onSelected(null);
        return false;
      },
      child: Scaffold(
        key: key,
        backgroundColor: Colors.transparent,
        appBar: AppBar(
          backgroundColor: Colors.transparent,
          elevation: 0.0,
          automaticallyImplyLeading: false,
          actions: <Widget>[
            FlatButton(
                onPressed: () {
                  widget.onSelected(null);
                },
                child: Text(
                  "Done",
                  style: TextStyle(
                      fontSize: 16.0,
                      fontWeight: FontWeight.normal,
                      color: Colors.white),
                ))
          ],
        ),
        body: Container(
          decoration: BoxDecoration(
              color: Colors.black54,
              borderRadius: BorderRadius.only(
                  topRight: Radius.circular(16.0),
                  topLeft: Radius.circular(16.0))),
          width: MediaQuery.of(context).size.width,
          height: MediaQuery.of(context).size.height,
          child: GridView.builder(
            gridDelegate:
                SliverGridDelegateWithFixedCrossAxisCount(crossAxisCount: 2),
            itemBuilder: (context, index) {
              return EaseInWidget(
                onTap: () {
                  widget.onSelected(SmileyData(
                      smileyPath: "assets/images/${smilies[index]}.png"));
                },
                child: Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: Image.asset(
                    "assets/images/${smilies[index]}.png",
                  ),
                ),
              );
            },
            itemCount: smilies.length,
            shrinkWrap: true,
          ),
        ),
      ),
    );
  }
}

==> 1.0.4.tar.gz: lib/src/widgets/smiley_add_widget.dart <==
import 'package:flutter/material.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_story/src/models/basic.dart';

class SmileyAddWidget extends StatefulWidget {
  final Function(StorySmileyData smileyData) onSelected;

  const SmileyAddWidget({Key key, @required this.onSelected}) : super(key: key);
  @override
  State<StatefulWidget> createState() => _SmileyAddWidgetState();
}

class _SmileyAddWidgetState extends State<SmileyAddWidget> {
  final GlobalKey<ScaffoldState> key = GlobalKey<ScaffoldState>();
  AnimationController controller;
  List<String> smilies = ["sticker1", "sticker2", "sticker3", "sticker4"];
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () async {
        widget.onSelected(null);
        return false;
      },
      child: Scaffold(
        key: key,
        backgroundColor: Colors.transparent,
        appBar: AppBar(
          backgroundColor: Colors.transparent,
          elevation: 0.0,
          automaticallyImplyLeading: false,
          actions: <Widget>[
            FlatButton(
                onPressed: () {
                  widget.onSelected(null);
                },
                child: Text(
                  "Done",
                  style: TextStyle(
                      fontSize: 16.0,
                      fontWeight: FontWeight.normal,
                      color: Colors.white),
                ))
          ],
        ),
        body: Container(
          decoration: BoxDecoration(
              color: Colors.black54,
              borderRadius: BorderRadius.only(
                  topRight: Radius.circular(16.0),
                  topLeft: Radius.circular(16.0))),
          width: MediaQuery.of(context).size.width,
          height: MediaQuery.of(context).size.height,
          child: GridView.builder(
            gridDelegate:
                SliverGridDelegateWithFixedCrossAxisCount(crossAxisCount: 2),
            itemBuilder: (context, index) {
              return EaseInWidget(
                onTap: () {
                  widget.onSelected(StorySmileyData(
                      smileyPath: "assets/images/${smilies[index]}.png"));
                },
                child: Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: Image.asset(
                    "assets/images/${smilies[index]}.png",
                  ),
                ),
              );
            },
            itemCount: smilies.length,
            shrinkWrap: true,
          ),
        ),
      ),
    );
  }
}
